@@ -49,12 +49,12 @@ void crashHandler( int )
 int main( int argc, char **argv )
 {
   AkApplication app( argc, argv );
-  app.setDescription( "Akonadi Control Process\nDo not run this manually, use 'akonadictl' instead to start/stop Akonadi." );
+  app.setDescription( QLatin1String("Akonadi Control Process\nDo not run this manually, use 'akonadictl' instead to start/stop Akonadi.") );
   app.parseCommandLine();
 
   // try to acquire the lock first, that means there is no second instance trying to start up at the same time
   // registering the real service name happens in AgentManager::continueStartup(), when everything is in fact up and running
-  if ( !QDBusConnection::sessionBus().registerService( AKONADI_DBUS_CONTROL_SERVICE_LOCK ) ) {
+  if ( !QDBusConnection::sessionBus().registerService( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE_LOCK) ) ) {
     // We couldn't register. Most likely, it's already running.
     const QString lastError = QDBusConnection::sessionBus().lastError().message();
     if (lastError.isEmpty())
@@ -64,7 +64,7 @@ int main( int argc, char **argv )
   }
 
   // older Akonadi server versions don't use the lock service yet, so check if one is already running before we try to start another one
-  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AKONADI_DBUS_CONTROL_SERVICE ) )
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) ) )
     akFatal() << "Another Akonadi control process is already running.";
 
   new ControlManager;
