@@ -36,7 +36,7 @@
 using namespace Akonadi;
 
 template <typename T>
-static bool intersect( const QList<typename T::Id> &l1, const QList<T> &l2 )
+static bool intersect( const QVector<typename T::Id> &l1, const QVector<T> &l2 )
 {
   foreach ( const T& e2, l2 ) {
     if ( l1.contains( e2.id() ) )
