@@ -21,12 +21,12 @@
 #define AKONADI_QUERYBUILDER_H
 
 #include "query.h"
-#include "../akonadiprivate_export.h"
 
 #include <QtCore/QPair>
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QVariant>
+#include <QtCore/QVector>
 #include <QtSql/QSqlQuery>
 
 #ifdef QUERYBUILDER_UNITTEST
@@ -38,7 +38,7 @@ namespace Akonadi {
 /**
   Helper class to construct arbitrary SQL queries.
 */
-class AKONADIPRIVATE_EXPORT QueryBuilder
+class QueryBuilder
 {
   public:
     enum QueryType {
@@ -52,7 +52,8 @@ class AKONADIPRIVATE_EXPORT QueryBuilder
       Unknown,
       Sqlite,
       MySQL,
-      PostgreSQL
+      PostgreSQL,
+      Virtuoso
     };
 
     /**
@@ -125,6 +126,13 @@ class AKONADIPRIVATE_EXPORT QueryBuilder
     */
     void addColumn( const QString &col );
 
+    /**
+     * Adds an aggregation statement.
+     * @param col The column to aggregate on
+     * @param aggregate The aggregation function.
+     */
+    void addAggregation( const QString &col, const QString &aggregate );
+
     /**
       Add a WHERE or HAVING condition which compares a column with a given value.
       @param column The column that should be compared.
@@ -236,9 +244,9 @@ class AKONADIPRIVATE_EXPORT QueryBuilder
     QueryType mType;
     QStringList mColumns;
     QList<QVariant> mBindValues;
-    QList<QPair<QString, Query::SortOrder> > mSortColumns;
+    QVector<QPair<QString, Query::SortOrder> > mSortColumns;
     QStringList mGroupColumns;
-    QList<QPair<QString, QVariant> > mColumnValues;
+    QVector<QPair<QString, QVariant> > mColumnValues;
 
     // we must make sure that the tables are joined in the correct order
     // QMap sorts by key which might invalidate the queries
